@@ -2,15 +2,17 @@
 //! # cargo_auto_lib
 //!
 //! **Library crate for common tasks when building rust projects. Intended for use with cargo-auto: automation tasks written in Rust language.**  
-//! ***version: 0.7.26 date: 2022-04-25 author: [Bestia.dev](.) repository: [Github](https://github.com/bestia-dev/cargo_auto_lib)***  
+//! ***version: 0.7.33 date: 2022-05-11 author: [Bestia.dev](https://bestia.dev) repository: [Github](https://github.com/bestia-dev/cargo_auto_lib)***  
 //!
-//! [![Lines in Rust code](https://img.shields.io/badge/Lines_in_Rust-1213-green.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
-//! [![Lines in Doc comments](https://img.shields.io/badge/Lines_in_Doc_comments-372-blue.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
-//! [![Lines in Comments](https://img.shields.io/badge/Lines_in_comments-128-purple.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
-//! [![Lines in examples](https://img.shields.io/badge/Lines_in_examples-0-yellow.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
-//! [![Lines in tests](https://img.shields.io/badge/Lines_in_tests-21-orange.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
+//! [![Lines in Rust code](https://img.shields.io/badge/Lines_in_Rust-1413-green.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
+//! [![Lines in Doc comments](https://img.shields.io/badge/Lines_in_Doc_comments-393-blue.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
+//! [![Lines in Comments](https://img.shields.io/badge/Lines_in_comments-167-purple.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
+//! [![Lines in examples](https://img.shields.io/badge/Lines_in_examples-31-yellow.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
+//! [![Lines in tests](https://img.shields.io/badge/Lines_in_tests-93-orange.svg)](https://github.com/bestia-dev/cargo_auto_lib/)
 //!
-//! [![crates.io](https://img.shields.io/crates/v/cargo_auto_lib.svg)](https://crates.io/crates/cargo_auto_lib) [![Documentation](https://docs.rs/cargo_auto_lib/badge.svg)](https://docs.rs/cargo_auto_lib/) [![crev reviews](https://web.crev.dev/rust-reviews/badge/crev_count/cargo_auto_lib.svg)](https://web.crev.dev/rust-reviews/crate/cargo_auto_lib/) [![Lib.rs](https://img.shields.io/badge/Lib.rs-rust-orange.svg)](https://lib.rs/crates/cargo_auto_lib/) [![Licence](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/bestia-dev/cargo_auto_lib/blob/master/LICENSE) [![Rust](https://github.com/bestia-dev/cargo_auto_lib/workflows/RustAction/badge.svg)](https://github.com/bestia-dev/cargo_auto_lib/)  
+//! [![crates.io](https://img.shields.io/crates/v/cargo_auto_lib.svg)](https://crates.io/crates/cargo_auto_lib) [![Documentation](https://docs.rs/cargo_auto_lib/badge.svg)](https://docs.rs/cargo_auto_lib/) [![crev reviews](https://web.crev.dev/rust-reviews/badge/crev_count/cargo_auto_lib.svg)](https://web.crev.dev/rust-reviews/crate/cargo_auto_lib/) [![Lib.rs](https://img.shields.io/badge/Lib.rs-rust-orange.svg)](https://lib.rs/crates/cargo_auto_lib/) [![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/bestia-dev/cargo_auto_lib/blob/master/LICENSE) [![Rust](https://github.com/bestia-dev/cargo_auto_lib/workflows/RustAction/badge.svg)](https://github.com/bestia-dev/cargo_auto_lib/) [![Hits](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fbestia-dev%2Fcargo_auto_lib&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false)](https://hits.seeyoufarm.com)  
+//!
+//! Hashtags: #rustlang #buildtool #developmenttool
 //!
 //! ## Try it
 //!
@@ -19,26 +21,24 @@
 //!
 //! ```bash
 //! cargo install cargo-auto
-//! cargo auto new with_lib
+//! cargo auto new
 //! ```
 //!
 //! In a new editor open the generated directory `automation_tasks_rs` as an independent rust project. There is already this dependency in `Cargo.toml`:  
 //!
 //! ```toml
-//! cargo_auto_lib="0.7.*"
+//! cargo_auto_lib="0.7.27"
 //! ```
 //!
 //! Preview the code and observe all the `auto_*` functions from `cargo_auto_lib`.  
 //! Example:  
 //!
-//! ```ignore
-//! fn task_release() {
-//!     auto_semver_increment_patch();
-//!     auto_cargo_toml_to_md();
-//!     auto_lines_of_code("");
-//!     auto_build();
-//! }
-//! ```
+//! fn task_release() {  
+//!     auto_semver_increment_patch();  
+//!     auto_cargo_toml_to_md();  
+//!     auto_lines_of_code("");  
+//!     auto_build();  
+//! }  
 //!
 //! Go back to your main rust project.  
 //! Add markers to the beginning of README.md (don't copy the numbers 1 and 2):  
@@ -88,22 +88,22 @@
 //!
 //! ## cargo crev reviews and advisory
 //!
-//! We leave in times of danger with [supply chain attacks](https://en.wikipedia.org/wiki/Supply_chain_attack).  
+//! We live in times of danger with [supply chain attacks](https://en.wikipedia.org/wiki/Supply_chain_attack).  
 //! It is recommended to always use [cargo-crev](https://github.com/crev-dev/cargo-crev)  
 //! to verify the trustworthiness of each of your dependencies.  
 //! Please, spread this info.  
-//! You can also read reviews quickly on the web. Example for the crate `num-traits`:  
-//! <https://web.crev.dev/rust-reviews/crate/num-traits/>  
+//! You can also read reviews quickly on the web:  
+//! <https://web.crev.dev/rust-reviews/crates/>  
 //!
 //! ## open-source free and free as a beer
 //!
-//! My open-source projects are free and free as a beer (MIT license).  
+//! My open-source projects are free as a beer (MIT license).  
 //! I just love programming.  
 //! But I need also to drink. If you find my projects and tutorials helpful,  
-//! please buy me a beer or two donating on my [paypal](https://paypal.me/LucianoBestia).  
+//! please buy me a beer donating on my [paypal](https://paypal.me/LucianoBestia).  
 //! You know the price of a beer in your local bar ;-)  
 //! So I can drink a free beer for your health :-)  
-//! [Na zdravje](https://translate.google.com/?hl=en&sl=sl&tl=en&text=Na%20zdravje&op=translate) !
+//! [Na zdravje!](https://translate.google.com/?hl=en&sl=sl&tl=en&text=Na%20zdravje&op=translate) [Alla salute!](https://dictionary.cambridge.org/dictionary/italian-english/alla-salute) [Prost!](https://dictionary.cambridge.org/dictionary/german-english/prost) [Nazdravlje!](https://matadornetwork.com/nights/how-to-say-cheers-in-50-languages/) 🍻
 //!
 // endregion: auto_md_to_doc_comments include README.md A //!
 
@@ -115,9 +115,11 @@ mod auto_delete_old_js_snippets_mod;
 mod auto_helper_functions_mod;
 mod auto_lines_of_code_mod;
 mod auto_md_to_doc_comments_mod;
+mod auto_plantuml_mod;
 mod auto_semver_mod;
 mod auto_semver_or_date_mod;
 mod auto_version_from_date_mod;
+
 pub mod utils_mod;
 
 // reexport functions for callers of the library
@@ -138,6 +140,9 @@ pub use auto_helper_functions_mod::UNHIDE_CURSOR;
 pub use auto_helper_functions_mod::YELLOW;
 pub use auto_lines_of_code_mod::auto_lines_of_code;
 pub use auto_md_to_doc_comments_mod::auto_md_to_doc_comments;
+pub use auto_plantuml_mod::auto_plantuml;
+pub use auto_plantuml_mod::auto_plantuml_for_path;
+pub use auto_plantuml_mod::hash_for_filename;
 pub use auto_semver_mod::auto_semver_increment_minor;
 pub use auto_semver_mod::auto_semver_increment_patch;
 pub use auto_semver_or_date_mod::auto_version_increment_semver_or_date;
